# Cognate Set Inspector

The cognate set inspection module allows you to search for patterns in your cognate sets. It simply displays occurrences of cognates in your data, and you can inspect the alignments at the same time by clicking on the cognate set identifier on the right. By clicking on the concepts on the left, you can filter the wordlist panel by these concepts. By double-clicking on the column headers, you can sort them in such a way that cognate sets are listed in decreasing order of occurrence. The selector on the left further offers you the possibility to search only for patterns which are, for example, exclusively shared between two, three, etc. languages. The module also displays gaps in certain set of concepts: if no cognate set and no concept matches the list of concepts shown in the right-most column, that is, if a translation for a given concept (or a given number of concepts) is missing in your data, this is indicated as such.